==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Transports/mms/translations/mms_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="32"/>
        <source>MMS Plugin</source>
        <translation>Engadido MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="52"/>
        <source>About MMS Transport Plugin</source>
        <translation>Sobre o engadido MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Engadido de transporte MMS de Qmmp</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Preferencias do engadido MMS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Tamaño de buffer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Transports/mms/translations/mms_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="33"/>
        <source>MMS Plugin</source>
        <translation>Engadido MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>About MMS Transport Plugin</source>
        <translation>Sobre o engadido MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Engadido de transporte MMS de Qmmp</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Preferencias do engadido MMS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Tamaño de buffer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
